@@ -1,5 +1,5 @@
 /******************************************************************************
-    (c) 1998-2000 P.J. Caulfield               patrick@tykepenguin.cix.co.uk
+    (c) 1998-2005 P.J. Caulfield               patrick@tykepenguin.cix.co.uk
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ static void get_env_as_args(char **argv[], int &argc, char *env);
 static void do_options(int argc, char *argv[],
 		       int &rfm, int &rat, int &org,
 		       int &interactive, int &keep_version, int &user_bufsize,
-		       int &remove_cr, int &show_stats, int &verbose, char *protection);
+		       int &remove_cr, int &show_stats, int &verbose, int &rrl, char *protection);
 
 // Start here:
 int main(int argc, char *argv[])
@@ -58,6 +58,7 @@ int main(int argc, char *argv[])
     int   last_infile;
     int   remove_cr = 0;
     int   show_stats = 0;
+    int   rrl = 0;
     char  opt;
     char  protection[255];
     struct timeval start_tv;
@@ -83,14 +84,14 @@ int main(int argc, char *argv[])
 	do_options(env_argc, env_argv,
 		   rfm, rat,org,
 		   interactive, keep_version, user_bufsize,
-		   remove_cr, show_stats, verbose, protection);
+		   remove_cr, show_stats, verbose, rrl, protection);
 
 
 // Parse the command-line options
     do_options(argc, argv,
 	       rfm, rat,org,
 	       interactive, keep_version, user_bufsize,
-	       remove_cr, show_stats, verbose, protection);
+	       remove_cr, show_stats, verbose, rrl, protection);
 
     // Work out the buffer size. The default for block transfers is 512
     // bytes unless the user specified otherwise.
@@ -151,7 +152,7 @@ int main(int argc, char *argv[])
     }
 
     // Set up the network links if necessary
-    if (out->setup_link(bufsize, rfm, rat, org))
+    if (out->setup_link(bufsize, rfm, rat, org, 0))
     {
 	out->perror("Error setting up output link");
 	return 1;
@@ -162,7 +163,7 @@ int main(int argc, char *argv[])
 
     for (filenum = optind; filenum < last_infile; filenum++)
     {
-	in = getFile(argv[filenum], verbose);
+	    in = getFile(argv[filenum], verbose);
 
 	// Now we have the first file name, if it is the only input file then
 	// we can check to see if it is a wildcard. If that is so then the
@@ -176,7 +177,7 @@ int main(int argc, char *argv[])
 	    }
 	}
 
-	if (in->setup_link(bufsize, rfm, rat, org))
+	if (in->setup_link(bufsize, rfm, rat, org, rrl))
 	{
 	    in->perror("Error setting up input link");
 	    return 1;
@@ -354,6 +355,7 @@ static void usage(char *name, int dntype, FILE *f)
         fprintf(f, "  -r <fmt>  (s)record format (fix, var, vfc, stm)\n");
         fprintf(f, "  -b <n>       use a block size of <n> bytes\n");
         fprintf(f, "  -d        (s)remove trailing CR on record (DOS file transfer)\n");
+        fprintf(f, "  -l        (r)Ignore interlocks on remote file\n");
         fprintf(f, "  -V           show version number\n");
         fprintf(f, "\n");
         fprintf(f, " (s) - only useful when sending files to VMS\n");
@@ -434,12 +436,12 @@ static void get_env_as_args(char **argv[], int &argc, char *env)
 static void do_options(int argc, char *argv[],
 		       int &rfm, int &rat, int &org,
 		       int &interactive, int &keep_version, int &user_bufsize,
-		       int &remove_cr, int &show_stats, int &verbose, char *protection)
+		       int &remove_cr, int &show_stats, int &verbose, int &rrl, char *protection)
 {
     int opt;
     opterr = 0;
     optind = 0;
-    while ((opt=getopt(argc,argv,"?Vvhdr:a:b:kism:p:")) != EOF)
+    while ((opt=getopt(argc,argv,"?Vvhdr:a:b:kislm:p:")) != EOF)
     {
 	switch(opt) {
 	case 'h':
@@ -454,6 +456,10 @@ static void do_options(int argc, char *argv[],
 	    verbose++;
 	    break;
 
+	case 'l':
+	    rrl = 1;
+	    break;
+
 	case 'r':
 	    if (tolower(optarg[0]) == 'f') rfm = file::RFM_FIX;
 	    if (tolower(optarg[0]) == 's') rfm = file::RFM_STM;
@@ -509,16 +515,17 @@ static void do_options(int argc, char *argv[],
 	    break;
 
 	case 'p':
+	    strcpy(protection, optarg);
 	    strcpy(protection, optarg);
 	    {
-	        // Validate protection
-		dap_protect_message prot;
-		if (prot.set_protection(protection) == -1) 
-		{
-		    fprintf(stderr, "Invalid VMS protection string\n");
-		    exit(1);
-		}
-	    }
+                    // Validate protection
+                    dap_protect_message prot;
+                    if (prot.set_protection(protection) == -1)
+                    {
+                            fprintf(stderr, "Invalid VMS protection string\n");
+                            exit(1);
+                    }
+            }
 	    break;
 
 	case 'd':
