@@ -398,6 +398,15 @@ void fal_task::make_unix_filespec(char *unixname, char *vmsname)
     // Copy the directory
     for (i=0; i< (int)strlen(dir); i++)
     {
+	// Remove '[]' as it's a no-op
+	if (dir[i] == '[' &&
+	    dir[i+1] == ']')
+	{
+	    i++;
+	    ptr = 0;
+	    continue;
+	}
+
 	// If the directory name starts [. then it is relative to the
 	// user's home directory and we lose the starting slash
 	// If there is also a volume name present then it all falls
@@ -615,6 +624,9 @@ bool fal_task::fake_file_type(unsigned int &blocksize, bool &send_records,
 {
     struct stat st;
 
+    if (stat(name, &st) == 0 && S_ISDIR(st.st_mode))
+	attrib_msg->set_fop_bit(dap_attrib_message::FB$DIR);
+
     // Ignore Directories
     if (stat(name, &st) == 0 && S_ISDIR(st.st_mode)) return false;
 
