@@ -16,6 +16,7 @@ class dap_item
  public:
     virtual bool read(dap_connection&) = 0;
     virtual bool write(dap_connection&) = 0;
+    virtual ~dap_item() {}
 };
 
 class dap_bytes : public dap_item // number of bytes
@@ -224,6 +225,19 @@ class dap_config_message: public dap_message
     static const int OS_OS8     = 11;
     static const int OS_RSX11MP = 12;
     static const int OS_COPOS11 = 13;
+    static const int OS_POS     = 14;
+    static const int OS_VAXLELN = 15;
+    static const int OS_CPM     = 16;
+    static const int OS_MSDOS   = 17;
+    static const int OS_ULTRIX  = 18;
+    static const int OS_ULTRIX11 = 19;
+    static const int OS_DTF_MVS = 21;
+    static const int OS_MACOS   = 22;
+    static const int OS_OS2     = 23;
+    static const int OS_DTF_VM  = 24;
+    static const int OS_OSF1    = 25;
+    static const int OS_WIN_NT  = 26;
+    static const int OS_WIN_95  = 27;
 
  private:
     dap_bytes bufsiz;
@@ -260,12 +274,14 @@ class dap_attrib_message: public dap_message
 	hbk(5),
 	ebk(5),
 	ffb(2),
-	sbn(5)
+        sbn(5),
+        jnl(4)
 	{msg_type = ATTRIB;}
 
     virtual bool read(dap_connection&);
     virtual bool write(dap_connection&);
 
+    int get_menu_bit(int);
     int get_datatype();
     int get_org();
     int get_rfm();
@@ -287,6 +303,7 @@ class dap_attrib_message: public dap_message
     int get_ebk();
     int get_ffb();
     int get_sbn();
+    int get_jnl();
 
     void set_datatype(int);
     void set_org(int);
@@ -318,6 +335,30 @@ class dap_attrib_message: public dap_message
     void set_file(const char *file, bool show_dev);
     unsigned long get_size();
 
+    // Bits in ATTMENU
+    static const int MENU_DATATYPE = 0;
+    static const int MENU_ORG = 1;
+    static const int MENU_RFM = 2;
+    static const int MENU_RAT = 3;
+    static const int MENU_BLS = 4;
+    static const int MENU_MRS = 5;
+    static const int MENU_ALQ = 6;
+    static const int MENU_BKS = 7;
+    static const int MENU_FSZ = 8;
+    static const int MENU_MRN = 9;
+    static const int MENU_RUNSYS = 10;
+    static const int MENU_DEQ = 11;
+    static const int MENU_FOP = 12;
+    static const int MENU_BSZ = 13;
+    static const int MENU_DEV = 14;
+    static const int MENU_SDC = 15;
+    static const int MENU_LRL = 16;
+    static const int MENU_HBK = 17;
+    static const int MENU_EBK = 18;
+    static const int MENU_FFB = 19;
+    static const int MENU_SBN = 20;
+    static const int MENU_JNL = 21;
+
     //DATATYPEs
     static const int ASCII      = 0;
     static const int IMAGE      = 1;
@@ -348,12 +389,14 @@ class dap_attrib_message: public dap_message
     static const int FB$PRN = 2;
     static const int FB$BLK = 3;
     static const int FB$LSA = 6;
+    static const int FB$MACY11 = 7;
 
     //FOPs:
     static const int FB$RWO = 0;
     static const int FB$RWC = 1;
     static const int FB$POS = 3;
     static const int FB$DLK = 4;
+    static const int FB$DIR = 5;
     static const int LOCKED = 6;
     static const int FB$CTG = 7;
     static const int FB$SUP = 8;
@@ -427,6 +470,7 @@ class dap_attrib_message: public dap_message
     dap_image ebk;
     dap_bytes ffb;
     dap_image sbn;
+    dap_ex    jnl;
 };
 
 //ACCESS message TYPE=3
@@ -476,6 +520,8 @@ class dap_access_message: public dap_message
     static const int FB$TRN = 4;
     static const int FB$BIO = 5;
     static const int FB$BRO = 6;
+    static const int FB$APP = 7; // FAC (Append)
+    static const int FB$NIL = 7; // SHR (no access by other users)
 
     // bits for DISPLAY
     static const int DISPLAY_MAIN    = 0;
@@ -486,6 +532,10 @@ class dap_access_message: public dap_message
     static const int DISPLAY_PROT    = 5;
     static const int DISPLAY_ACL     = 7;
     static const int DISPLAY_NAME    = 8;
+    static const int DISPLAY_3PTNAME = 9;
+    static const int DISPLAY_COLLTBL = 10;
+    static const int DISPLAY_CDA     = 11;
+    static const int DISPLAY_TCL     = 12;
 
     // masks for DISPLAY
     static const int DISPLAY_MAIN_MASK    =   1;
@@ -496,6 +546,10 @@ class dap_access_message: public dap_message
     static const int DISPLAY_PROT_MASK    =  32;
     static const int DISPLAY_ACL_MASK     = 128;
     static const int DISPLAY_NAME_MASK    = 256;
+    static const int DISPLAY_3PTNAME_MASK = 512;
+    static const int DISPLAY_COLLTBL_MASK = 1024;
+    static const int DISPLAY_CDA_MASK    = 2048;
+    static const int DISPLAY_TCL_MASK    = 4096;
 
  private:
     dap_bytes accfunc;
@@ -519,7 +573,9 @@ class dap_control_message: public dap_message
 	krf(1),
         rop(6),
 	hsh(5),
-        display(4)
+        display(4),
+	blkcnt(1),
+	usz(2)
 	{msg_type = CONTROL;}
 
     virtual bool read(dap_connection&);
@@ -533,6 +589,8 @@ class dap_control_message: public dap_message
     void set_rop_bit(int f);
     void set_rop(int f);
     void set_display(int);
+    void set_blkcnt(int);
+    void set_usz(int);
 
     int   get_ctlfunc();
     int   get_rac();
@@ -541,6 +599,8 @@ class dap_control_message: public dap_message
     bool  get_rop_bit(int f);
     int   get_display();
     unsigned long get_long_key();
+    int   get_blkcnt();
+    int   get_usz();
 
     // ctlfunc - Control functions:
     static const int GET            = 1;
@@ -587,7 +647,13 @@ class dap_control_message: public dap_message
     static const int RB$NLK  = 11;
     static const int RB$RLK  = 12;
     static const int RB$BIO  = 13;
-    static const int RB$NXR  = 14;
+    static const int RB$LIM  = 14;
+    static const int RB$NXR  = 15;
+    static const int RB$WAT  = 16;
+    static const int RB$RRL  = 17;
+    static const int RB$REA  = 18;
+    static const int RB$KLE  = 19;
+    static const int RB$KLT  = 20;
 
  private:
     dap_bytes ctlfunc;
@@ -598,6 +664,8 @@ class dap_control_message: public dap_message
     dap_ex    rop;
     dap_image hsh;
     dap_ex    display;
+    dap_bytes blkcnt;
+    dap_bytes usz;
 };
 
 //CONTRAN (Continue Transfer) message TYPE=5
@@ -615,6 +683,8 @@ class dap_contran_message: public dap_message
     static const int SKIP      = 2;
     static const int ABORT     = 3;
     static const int RESUME    = 4;
+    static const int TERMINATE = 5;
+    static const int RESYNC    = 6;
 
     int get_confunc();
     void set_confunc(int f);
@@ -663,6 +733,9 @@ class dap_accomp_message: public dap_message
     static const int PURGE         = 3;
     static const int END_OF_STREAM = 4;
     static const int SKIP          = 5;
+    static const int CHANGE_BEGIN  = 6;
+    static const int CHANGE_END    = 7;
+    static const int TERMINATE     = 8;
 
  private:
     dap_bytes cmpfunc;
